export

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

templ: version: v0.3.857

Index

Constants

const (
	ExportFormatExcel = ExportFormat(iota + 1)
	ExportFormatCSV
	ExportFormatJSON
	ExportFormatTXT
)

Variables

This section is empty.

Functions

func ExportDropdown

func ExportDropdown(props ExportDropdownProps) templ.Component

func GetExportFormatString

func GetExportFormatString(format ExportFormat) string

GetExportFormatString returns the string representation of an ExportFormat

func IsValidExportFormat

func IsValidExportFormat(formatStr string) bool

IsValidExportFormat checks if a string is a valid export format

Types

type ExportDropdownProps

type ExportDropdownProps struct {
	Formats   []ExportFormat
	ExportURL string
	Label     string
	Size      button.Size
	Class     string
	Attrs     templ.Attributes
}

type ExportFormat

type ExportFormat int

func GetExportFormat

func GetExportFormat(r *http.Request) (ExportFormat, bool)

GetExportFormat extracts and validates the export format from an HTTP request

Jump to