Documentation
¶
Overview ¶
templ: version: v0.3.857
Index ¶
Constants ¶
const ( ExportFormatExcel = ExportFormat(iota + 1) ExportFormatCSV ExportFormatJSON ExportFormatTXT )
Variables ¶
This section is empty.
Functions ¶
func ExportDropdown ¶
func ExportDropdown(props ExportDropdownProps) templ.Component
func GetExportFormatString ¶
func GetExportFormatString(format ExportFormat) string
GetExportFormatString returns the string representation of an ExportFormat
func IsValidExportFormat ¶
IsValidExportFormat checks if a string is a valid export format
Types ¶
type ExportDropdownProps ¶
type ExportDropdownProps struct {
Formats []ExportFormat
ExportURL string
Label string
Size button.Size
Class string
Attrs templ.Attributes
}
type ExportFormat ¶
type ExportFormat int
func GetExportFormat ¶
func GetExportFormat(r *http.Request) (ExportFormat, bool)
GetExportFormat extracts and validates the export format from an HTTP request
Click to show internal directories.
Click to hide internal directories.